@@ -17,6 +17,7 @@ import ddt
 import testtools
 
 from tempest.lib.common.utils import data_utils
+from tempest.lib import exceptions
 
 from manilaclient.common import constants
 from manilaclient import config
@@ -26,6 +27,7 @@ from manilaclient.tests.functional import utils
 CONF = config.CONF
 
 
+@ddt.ddt
 class SharesReadWriteBase(base.BaseTestCase):
     protocol = None
 
@@ -52,6 +54,7 @@ class SharesReadWriteBase(base.BaseTestCase):
         create = self.create_share(
             self.protocol, name=name, client=self.user_client)
 
+        self.assertEqual("creating", create['status'])
         self.assertEqual(name, create['name'])
         self.assertEqual('1', create['size'])
         self.assertEqual(self.protocol.upper(), create['share_proto'])
@@ -90,6 +93,30 @@ class SharesReadWriteBase(base.BaseTestCase):
         self.assertEqual('1', get['size'])
         self.assertEqual(self.protocol.upper(), get['share_proto'])
 
+    def test_create_delete_with_wait(self):
+        name = data_utils.rand_name('share-with-wait-%s')
+        description = data_utils.rand_name('we-wait-until-share-is-ready')
+
+        share_1, share_2 = (
+            self.create_share(self.protocol, name=(name % num),
+                              description=description,
+                              use_wait_option=True,
+                              client=self.user_client)
+            for num in range(0, 2)
+        )
+
+        self.assertEqual("available", share_1['status'])
+        self.assertEqual("available", share_2['status'])
+
+        self.delete_share([share_1['id'], share_2['id']],
+                          wait=True,
+                          client=self.user_client)
+
+        for share in (share_1, share_2):
+            self.assertRaises(exceptions.NotFound,
+                              self.user_client.get_share,
+                              share['id'])
+
 
 @ddt.ddt
 class SharesTestMigration(base.BaseTestCase):
